# Fireworks AI Python library

[![PyPI Version](https://img.shields.io/pypi/v/fireworks-ai.svg)](https://pypi.org/project/fireworks-ai/)
[![License: MIT](https://img.shields.io/badge/License-MIT-yellow.svg)](https://opensource.org/licenses/MIT)

[Fireworks AI](https://fireworks.ai/) is a platform for application developers
and machine learning engineers to build, experiment, and deploy open-source models. Our
platform is built upon the fastest and most efficient engine for deploying
open-source models in production.

To access all of our capabilities, we offer an idiomatic Python SDK that provides
a developer-friendly experience from prototype to production.

## Getting Started

See [the tutorial](http://docs.fireworks.ai/tools-sdks/python-client/the-tutorial) to get started.

## Installation

This package requires Python 3.9 or higher.

```sh
pip install fireworks-ai
```